==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Tux/Resources/translations/Tux_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Selecteer</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Inzoomen</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Draaien</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Pan</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Kantelen</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Navigatie stijl</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up of Page Down toets.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Rotatie focus</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Middelste muisknop.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Navigatie stijl is niet herkend.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Instellingen</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Orbit stijl</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Compact</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Tooltip</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Draaitafel</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>niet gedefinieerd</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or H key.</source>
      <translation>Middelste muisknop of toets H.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Tux/Resources/translations/Tux_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="nl" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="NavigationIndicatorGui.py" line="63"/>
      <source>Select</source>
      <translation>Selecteer</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="64"/>
      <source>Zoom</source>
      <translation>Inzoomen</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="65"/>
      <source>Rotate</source>
      <translation>Draaien</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="66"/>
      <source>Pan</source>
      <translation>Pan</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="67"/>
      <source>Tilt</source>
      <translation>Kantelen</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="68"/>
      <source>Navigation style</source>
      <translation>Navigatie stijl</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="69"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up of Page Down toets.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="70"/>
      <source>Rotation focus</source>
      <translation>Rotatie focus</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="73"/>
      <source>Middle mouse button.</source>
      <translation>Middelste muisknop.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="76"/>
      <source>Navigation style not recognized.</source>
      <translation>Navigatie stijl is niet herkend.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Instellingen</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Orbit stijl</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Compact</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Tooltip</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Draaitafel</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>niet gedefinieerd</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button or H key.</source>
      <translation>Middelste muisknop of toets H.</translation>
    </message>
  </context>
</TS>
